@@ -61,7 +61,7 @@ use LWP::UserAgent;
 use List::Util qw(pairs any);
 use MIME::Base64;
 use POSIX::strptime qw(strptime);
-use Scalar::Util    qw(reftype);
+use Scalar::Util qw(reftype);
 use Time::Local;
 
 use constant {  ## no critic (ProhibitConstantPragma, Capitalization)
@@ -101,7 +101,7 @@ use constant {  ## no critic (ProhibitConstantPragma, Capitalization)
   X_AMZ_SSO_BEARER_TOKEN        => ':x-amz-sso_bearer_token',
 };
 
-our $VERSION = '1.1.23';  ## no critic (RequireInterpolation)
+our $VERSION = '1.1.24';  ## no critic (RequireInterpolation)
 
 our @EXPORT_OK
   = qw( create_passkey set_sso_credentials get_role_credentials );
@@ -1535,7 +1535,7 @@ Options
   export AWS_SECRET_ACCESS_KEY=****************************************
 
  $ aws sso login
- $ amazon-credentials.sh --role my-sso-role --account 01234567890
+ $ amazon-credentials --role my-sso-role --account 01234567890
 
 END_OF_USAGE
   }
@@ -1600,7 +1600,7 @@ sub main {
     return 'env'
       if $options{env};
 
-    return 'container'
+    return 'role'
       if $options{ec2};
 
     return 'container'
@@ -1682,7 +1682,7 @@ or pass your SSO role name and account ID...
  
 =head1 VERSION
 
-This document reverse to verion 1.1.23 of
+This document reverse to verion 1.1.24 of
 L<Amazon::Credentials>.
 
 =head1 METHODS AND SUBROUTINES
